Module app

Module app 

Structs

Subsystem
Compile-time subsystem identity embedded in generated Copper applications.

Traits

CuApplication
A trait that defines the structure and behavior of a CuApplication.
CuDistributedReplayApplication
Simulation-enabled applications that can be instantiated for distributed replay.
CuRecordedReplayApplication
Simulation-enabled applications that can replay a recorded CopperList verbatim.
CuSimApplication
A trait that defines the structure and behavior of a simulation-enabled CuApplication.
CuStdApplication
Convenience trait for CuApplication when it is just a std App
CuSubsystemMetadata
Compile-time subsystem identity embedded in generated Copper applications.