CuDistributedReplayApplication

Trait CuDistributedReplayApplication 

pub trait CuDistributedReplayApplication<S: SectionStorage, L: UnifiedLogWrite<S> + 'static>: CuRecordedReplayApplication<S, L> + CuSubsystemMetadata {
    // Required method
    fn build_distributed_replay(
        clock: RobotClock,
        unified_logger: Arc<Mutex<L>>,
        instance_id: u32,
        config_override: Option<CuConfig>,
    ) -> CuResult<Self>
       where Self: Sized;
}
Simulation-enabled applications that can be instantiated for distributed replay.

This extends exact-output replay with the one extra capability the distributed engine needs: build a replayable app for a specific deployment instance_id while keeping app construction type-safe.

Required Methods

fn build_distributed_replay( clock: RobotClock, unified_logger: Arc<Mutex<L>>, instance_id: u32, config_override: Option<CuConfig>, ) -> CuResult<Self>
where Self: Sized,

Build this app for deterministic distributed replay.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors