pub enum ConfigGraphs {
Simple(CuGraph),
Missions(HashMap<String, CuGraph>),
}Variants
Implementations
Sourceimpl ConfigGraphs
impl ConfigGraphs
Sourcepub fn get_all_missions_graphs(&self) -> HashMap<String, CuGraph>
pub fn get_all_missions_graphs(&self) -> HashMap<String, CuGraph>
Returns a consistent hashmap of mission names to Graphs whatever the shape of the config is. Note: if there is only one anonymous mission it will be called “default”
pub fn get_default_mission_graph(&self) -> CuResult<&CuGraph>
pub fn get_graph(&self, mission_id: Option<&str>) -> CuResult<&CuGraph>
pub fn get_graph_mut( &mut self, mission_id: Option<&str>, ) -> CuResult<&mut CuGraph>
pub fn add_mission(&mut self, mission_id: &str) -> CuResult<&mut CuGraph>