pub struct ComponentConfig(pub HashMap<String, Value>);Expand description
This is the configuration of a component (like a task config or a monitoring config):w It is a map of key-value pairs. It is given to the new method of the task implementation.
Tuple Fields
0: HashMap<String, Value>Implementations
Sourceimpl ComponentConfig
impl ComponentConfig
pub fn new() -> Self
pub fn get<T>(&self, key: &str) -> Result<Option<T>, ConfigError>
Sourcepub fn get_value<T>(&self, key: &str) -> Result<Option<T>, ConfigError>where
T: DeserializeOwned,
pub fn get_value<T>(&self, key: &str) -> Result<Option<T>, ConfigError>where
T: DeserializeOwned,
Retrieve a structured config value by deserializing it with cu29-value.
Example RON:
{ "calibration": { "matrix": [[1.0, 0.0, 0.0], [0.0, 1.0, 0.0], [0.0, 0.0, 1.0]], "enabled": true } }
ⓘ
#[derive(serde::Deserialize)]
struct CalibrationCfg {
matrix: [[f32; 3]; 3],
enabled: bool,
}
let cfg: CalibrationCfg = config.get_value("calibration")?.unwrap();pub fn set<T: Into<Value>>(&mut self, key: &str, value: T)