pub struct LoggingConfig {
pub enable_task_logging: bool,
pub slab_size_mib: Option<u64>,
pub section_size_mib: Option<u64>,
pub keyframe_interval: Option<u32>,
}Fields
enable_task_logging: boolEnable task logging to the log file.
slab_size_mib: Option<u64>Size of each slab in the log file. (it is the size of the memory mapped file at a time)
section_size_mib: Option<u64>Pre-allocated size for each section in the log file.
keyframe_interval: Option<u32>Interval in copperlists between two “keyframes” in the log file i.e. freezing tasks.
Implementations