pub fn validate_replay_continuity(
expected: u64,
actual: u64,
keyframe: Option<u64>,
) -> CuResult<()>Expand description
Rejects replay across missing history unless state is restored at this boundary. Call before executing any task or changing the replay clock.