pub enum OwnedCopperListSubmission<P: CopperListTuple> {
Recycled(Box<CopperList<P>>),
Pending,
}Expand description
Result of handing an owned boxed CopperList to the runtime-side CL I/O path.
Variants
Recycled(Box<CopperList<P>>)
The CL has been fully handled and can be recycled immediately by the caller.
Pending
The CL was queued asynchronously and will be returned by a later reclaim call.