pub struct CuExecutionStep {
pub node_id: NodeId,
pub node: Node,
pub task_type: CuTaskType,
pub input_msg_indices_types: Vec<CuInputMsg>,
pub output_msg_pack: Option<CuOutputPack>,
}Expand description
This structure represents a step in the execution plan.
Fields
node_id: NodeIdNodeId: node id of the task to execute
node: NodeNode: node instance
task_type: CuTaskTypeCuTaskType: type of the task
input_msg_indices_types: Vec<CuInputMsg>the indices in the copper list of the input messages and their types
output_msg_pack: Option<CuOutputPack>the index in the copper list of the output message and its type