pub struct KeyFrame {
pub culistid: u64,
pub timestamp: CuTime,
pub serialized_tasks: Vec<u8>,
}Expand description
A keyframe records a distributed snapshot of component state around a copperlist.
serialized_tasks contains a versioned sequence of length-framed component
snapshots in their generated execution-wave freeze order.
Fields
culistid: u64timestamp: CuTimeserialized_tasks: Vec<u8>Trait Implementations
Sourceimpl<'__de, __Context> BorrowDecode<'__de, __Context> for KeyFrame
impl<'__de, __Context> BorrowDecode<'__de, __Context> for KeyFrame
Sourcefn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>(
decoder: &mut __D,
) -> Result<Self, DecodeError>
fn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>( decoder: &mut __D, ) -> Result<Self, DecodeError>
Attempt to decode this type with the given BorrowDecode.