LoopRateLimiter

Struct LoopRateLimiter 

pub struct LoopRateLimiter { /* private fields */ }
Runtime loop limiter that preserves phase with absolute deadlines.

This is intentionally a small runtime helper so generated applications do not have to open-code loop scheduling policy. Deadlines are tracked against the provided RobotClock, even when sysclock-perf is enabled for process-time measurements.

Implementations

Source

impl LoopRateLimiter

pub fn from_rate_target_hz( rate_target_hz: u64, clock: &RobotClock, ) -> CuResult<Self>

pub fn is_ready(&self, clock: &RobotClock) -> bool

pub fn remaining(&self, clock: &RobotClock) -> Option<CuDuration>

pub fn wait_until_ready(&self, clock: &RobotClock)

pub fn mark_tick(&mut self, clock: &RobotClock)

pub fn limit(&mut self, clock: &RobotClock)