pub struct CuStampedData<T, M>where
T: CuMsgPayload,
M: Metadata,{
pub tov: Tov,
pub metadata: M,
/* private fields */
}Expand description
CuMsg is the envelope holding the msg payload and the metadata between tasks.
Fields
tov: TovThe time of validity of the message. It can be undefined (None), one measure point or a range of measures (TimeRange).
metadata: MThis metadata is the data that is common to all messages.
Implementations
Sourceimpl<T, M> CuStampedData<T, M>where
T: CuMsgPayload,
M: Metadata,
impl<T, M> CuStampedData<T, M>where
T: CuMsgPayload,
M: Metadata,
pub fn new(payload: Option<T>) -> Self
pub fn payload(&self) -> Option<&T>
pub fn set_payload(&mut self, payload: T)
pub fn clear_payload(&mut self)
pub fn payload_mut(&mut self) -> &mut Option<T>
Sourceimpl<T: CuMsgPayload> CuStampedData<T, CuMsgMetadata>
impl<T: CuMsgPayload> CuStampedData<T, CuMsgMetadata>
Sourcepub unsafe fn assume_payload<U: CuMsgPayload>(&self) -> &CuMsg<U>
pub unsafe fn assume_payload<U: CuMsgPayload>(&self) -> &CuMsg<U>
Reinterprets the payload type carried by this message.
Safety
The caller must guarantee that the message really contains a payload of type U. Failing
to do so is undefined behaviour.
Sourcepub unsafe fn assume_payload_mut<U: CuMsgPayload>(&mut self) -> &mut CuMsg<U>
pub unsafe fn assume_payload_mut<U: CuMsgPayload>(&mut self) -> &mut CuMsg<U>
Mutable variant of assume_payload.
Safety
The caller must guarantee that mutating the returned message is sound for the actual payload type stored in the buffer.
Sourceimpl<T: CuMsgPayload + 'static> CuStampedData<T, CuMsgMetadata>
impl<T: CuMsgPayload + 'static> CuStampedData<T, CuMsgMetadata>
Sourcepub fn downcast_ref<U: CuMsgPayload + 'static>(&self) -> CuResult<&CuMsg<U>>
pub fn downcast_ref<U: CuMsgPayload + 'static>(&self) -> CuResult<&CuMsg<U>>
Attempts to view this message as carrying payload U.
Sourcepub fn downcast_mut<U: CuMsgPayload + 'static>(
&mut self,
) -> CuResult<&mut CuMsg<U>>
pub fn downcast_mut<U: CuMsgPayload + 'static>( &mut self, ) -> CuResult<&mut CuMsg<U>>
Mutable variant of downcast_ref.