pub trait Freezable {
// Provided methods
fn freeze<E: Encoder>(&self, encoder: &mut E) -> Result<(), EncodeError> { ... }
fn thaw<D: Decoder>(&mut self, _decoder: &mut D) -> Result<(), DecodeError> { ... }
}Expand description
The internal state of a task needs to be serializable so the framework can take a snapshot of the task graph.
Provided Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".