pub struct DistributedReplayBuilder { /* private fields */ }Expand description
Builder for a validated distributed replay plan.
Implementations
Sourceimpl DistributedReplayBuilder
impl DistributedReplayBuilder
Sourcepub fn new(multi_config_path: impl AsRef<Path>) -> CuResult<Self>
pub fn new(multi_config_path: impl AsRef<Path>) -> CuResult<Self>
Load a strict multi-Copper config and start building a distributed replay plan.
Sourcepub fn with_catalog(self, catalog: DistributedReplayCatalog) -> Self
pub fn with_catalog(self, catalog: DistributedReplayCatalog) -> Self
Replace the discovered catalog explicitly.
Sourcepub fn discover_logs<I, P>(self, inputs: I) -> CuResult<Self>
pub fn discover_logs<I, P>(self, inputs: I) -> CuResult<Self>
Discover logs from files and/or directories.
Directories are walked recursively by DistributedReplayCatalog.
Sourcepub fn discover_logs_under(self, root: impl AsRef<Path>) -> CuResult<Self>
pub fn discover_logs_under(self, root: impl AsRef<Path>) -> CuResult<Self>
Convenience wrapper for recursive discovery under one root directory.
Sourcepub fn instances<I>(self, instances: I) -> Selfwhere
I: IntoIterator<Item = u32>,
pub fn instances<I>(self, instances: I) -> Selfwhere
I: IntoIterator<Item = u32>,
Restrict plan construction to a subset of instance ids.
Sourcepub fn register<App>(self, subsystem_id: &str) -> CuResult<Self>where
App: CuDistributedReplayApplication<NoopSectionStorage, NoopLogger> + CuDistributedReplayApplication<MmapSectionStorage, UnifiedLoggerWrite> + 'static,
pub fn register<App>(self, subsystem_id: &str) -> CuResult<Self>where
App: CuDistributedReplayApplication<NoopSectionStorage, NoopLogger> + CuDistributedReplayApplication<MmapSectionStorage, UnifiedLoggerWrite> + 'static,
Register the generated app type expected for one subsystem.
Sourcepub fn build(self) -> CuResult<DistributedReplayPlan>
pub fn build(self) -> CuResult<DistributedReplayPlan>
Validate discovery + registrations and prepare a typed replay plan.