pub struct DistributedReplayLog {
pub base_path: PathBuf,
pub stack: RuntimeLifecycleStackInfo,
pub config_source: RuntimeLifecycleConfigSource,
pub effective_config_ron: String,
pub mission: Option<String>,
}Expand description
One discovered Copper log that can participate in distributed replay.
Fields
base_path: PathBufstack: RuntimeLifecycleStackInfoconfig_source: RuntimeLifecycleConfigSourceeffective_config_ron: Stringmission: Option<String>Implementations
Sourceimpl DistributedReplayLog
impl DistributedReplayLog
Sourcepub fn discover(path: impl AsRef<Path>) -> CuResult<Self>
pub fn discover(path: impl AsRef<Path>) -> CuResult<Self>
Discover a single Copper log from either its base path (foo.copper) or
one of its slab paths (foo_0.copper, foo_1.copper, …).
pub fn instance_id(&self) -> u32
pub fn subsystem_code(&self) -> u16
pub fn subsystem_id(&self) -> Option<&str>