pub struct CopperListIoStats {
pub raw_culist_bytes: u64,
pub handle_bytes: u64,
pub encoded_culist_bytes: u64,
pub keyframe_bytes: u64,
pub structured_log_bytes_total: u64,
pub culistid: u32,
}Expand description
Reported data about CopperList IO for a single iteration.
Fields
raw_culist_bytes: u64CopperList struct size in RAM (excluding dynamic payloads/handles)
handle_bytes: u64Bytes held by payloads that will be serialized (currently: pooled handles, vecs, slices)
encoded_culist_bytes: u64Bytes produced by bincode serialization of the CopperList
keyframe_bytes: u64Bytes produced by bincode serialization of the KeyFrame (0 if none)
structured_log_bytes_total: u64Cumulative bytes written to the structured log stream so far
culistid: u32CopperList identifier for reference in monitors