pub struct CuArrayVec<T, const N: usize>(pub ArrayVec<T, N>);Expand description
A Copper-friendly wrapper around ArrayVec with bincode serialization support.
This provides a fixed-capacity, stack-allocated vector that can be efficiently serialized and deserialized. It is particularly useful for message payloads that need to avoid heap allocations while supporting varying lengths of data up to a maximum.
Unlike standard Vec, CuArrayVec will never reallocate or use the heap for the elements storage.
Tuple Fields
0: ArrayVec<T, N>Trait Implementations
Sourceimpl<'de, T, const N: usize> BorrowDecode<'de, ()> for CuArrayVec<T, N>where
T: BorrowDecode<'de, ()> + 'static,
impl<'de, T, const N: usize> BorrowDecode<'de, ()> for CuArrayVec<T, N>where
T: BorrowDecode<'de, ()> + 'static,
Sourcefn borrow_decode<D: BorrowDecoder<'de, Context = ()>>(
decoder: &mut D,
) -> Result<Self, DecodeError>
fn borrow_decode<D: BorrowDecoder<'de, Context = ()>>( decoder: &mut D, ) -> Result<Self, DecodeError>
Attempt to decode this type with the given BorrowDecode.
Sourceimpl<T: Clone, const N: usize> Clone for CuArrayVec<T, N>
impl<T: Clone, const N: usize> Clone for CuArrayVec<T, N>
Sourcefn clone(&self) -> CuArrayVec<T, N>
fn clone(&self) -> CuArrayVec<T, N>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<T, const N: usize> Default for CuArrayVec<T, N>
impl<T, const N: usize> Default for CuArrayVec<T, N>