Struct DynamicSet
pub struct DynamicSet { /* private fields */ }Expand description
An unordered set of reflected values.
Implementations
impl DynamicSet
impl DynamicSet
pub fn set_represented_type(
&mut self,
represented_type: Option<&'static TypeInfo>,
)
pub fn set_represented_type( &mut self, represented_type: Option<&'static TypeInfo>, )
Sets the type to be represented by this DynamicSet.
Panics
Panics if the given type is not a TypeInfo::Set.