ResourceBundle

Trait ResourceBundle 

pub trait ResourceBundle: ResourceBundleDecl + Sized {
    const INPUT_NAMES: &'static [&'static str] = _;

    // Required method
    fn build(
        bundle: BundleContext<Self>,
        config: Option<&ComponentConfig>,
        manager: &mut ResourceManager,
    ) -> CuResult<()>;
}
Bundle providers implement this trait to populate the ResourceManager with concrete resources for a given bundle id.

Provided Associated Constants

const INPUT_NAMES: &'static [&'static str] = _

Dependencies consumed during construction. Existing bundles have none.

Required Methods

fn build( bundle: BundleContext<Self>, config: Option<&ComponentConfig>, manager: &mut ResourceManager, ) -> CuResult<()>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors