pub enum SimOverride {
ExecutedBySim,
ExecuteByRuntime,
Errored(String),
}Expand description
This is the answer the simulator can give to control the simulation flow.
Variants
ExecutedBySim
The callback took care of the logic on the simulation side and the actual implementation needs to be skipped.
ExecuteByRuntime
The actual implementation needs to be executed.
Errored(String)
Emulated the behavior of an erroring task (same as return Err(..) in the normal tasks methods).