pub fn build_pool(spec: &ThreadPoolConfig) -> CuResult<ThreadPool>Expand description
Builds a rayon thread pool from a declarative ThreadPoolConfig, applying
the configured CPU affinity and scheduling policy/priority to each worker.
pub fn build_pool(spec: &ThreadPoolConfig) -> CuResult<ThreadPool>Builds a rayon thread pool from a declarative ThreadPoolConfig, applying
the configured CPU affinity and scheduling policy/priority to each worker.