pub struct LoggingConfig {
pub enable_task_logging: bool,
pub enable_keyframe_logging: bool,
pub copperlist_count: Option<usize>,
pub slab_size_mib: Option<u64>,
pub section_size_mib: Option<u64>,
pub keyframe_interval: Option<u32>,
pub codecs: Vec<LoggingCodecSpec>,
}Fields
enable_task_logging: boolEnable task logging to the log file.
enable_keyframe_logging: boolGenerate and record task-state keyframes.
Without another generated keyframe consumer, this is a compile-time application
property and #[copper_runtime] emits no capture calls when it is false.
A log-stream destination independently requests keyframe capture for recovery points.
copperlist_count: Option<usize>Number of preallocated CopperLists available to the runtime.
This is consumed by proc-macro codegen and must match the value compiled into the application binary.
slab_size_mib: Option<u64>Size of each slab in the log file. (it is the size of the memory mapped file at a time)
section_size_mib: Option<u64>Pre-allocated size for each section in the log file.
keyframe_interval: Option<u32>Interval in copperlists between two “keyframes” in the log file i.e. freezing tasks.
codecs: Vec<LoggingCodecSpec>Named log codec specs reusable across task output bindings.
Implementations