pub struct KeyFramesManager {
pub last_encoded_bytes: u64,
/* private fields */
}Expand description
Manages the frozen tasks state and logging.
Fields
last_encoded_bytes: u64Bytes written by the last keyframe log
Implementations
Sourceimpl KeyFramesManager
impl KeyFramesManager
pub fn reset(&mut self, culistid: u32, clock: &RobotClock)
Sourcepub fn set_forced_timestamp(&mut self, ts: CuTime)
pub fn set_forced_timestamp(&mut self, ts: CuTime)
Force the timestamp of the next keyframe to a given value.
pub fn freeze_task( &mut self, culistid: u32, task: &impl Freezable, ) -> CuResult<usize>
Sourcepub fn freeze_any(
&mut self,
culistid: u32,
item: &impl Freezable,
) -> CuResult<usize>
pub fn freeze_any( &mut self, culistid: u32, item: &impl Freezable, ) -> CuResult<usize>
Generic helper to freeze any Freezable state (task or bridge) into the current keyframe.
pub fn end_of_processing(&mut self, culistid: u32) -> CuResult<()>
Sourcepub fn lock_keyframe(&mut self, keyframe: &KeyFrame)
pub fn lock_keyframe(&mut self, keyframe: &KeyFrame)
Preload a recorded keyframe so it is logged verbatim on the matching CL.