pub struct CuMsgMetadata {
pub process_time: PartialCuTimeRange,
pub status_txt: CuCompactString,
}Expand description
CuMsgMetadata is a structure that contains metadata common to all CuStampedDataSet.
Fields
process_time: PartialCuTimeRangeThe time range used for the processing of this message
status_txt: CuCompactStringA small string for real time feedback purposes. This is useful for to display on the field when the tasks are operating correctly.
Implementations
Sourceimpl CuMsgMetadata
impl CuMsgMetadata
pub fn set_status(&mut self, status: impl ToCompactString)