pub trait CuSingleOutputMsg {
type Payload: CuMsgPayload;
}Expand description
Helper trait used by codegen when Copper needs to treat a task output as a single message slot without relying on config-declared output edges.
pub trait CuSingleOutputMsg {
type Payload: CuMsgPayload;
}Helper trait used by codegen when Copper needs to treat a task output as a single message slot without relying on config-declared output edges.