pub struct DistributedReplayPlan {
pub multi_config_path: PathBuf,
pub multi_config: MultiCopperConfig,
pub catalog: DistributedReplayCatalog,
pub selected_instances: Vec<u32>,
pub mission: Option<String>,
pub registrations: Vec<DistributedReplayAppRegistration>,
pub assignments: Vec<DistributedReplayAssignment>,
}Expand description
Validated replay plan produced by DistributedReplayBuilder.
Fields
multi_config_path: PathBufmulti_config: MultiCopperConfigcatalog: DistributedReplayCatalogselected_instances: Vec<u32>mission: Option<String>registrations: Vec<DistributedReplayAppRegistration>assignments: Vec<DistributedReplayAssignment>Implementations
Sourceimpl DistributedReplayPlan
impl DistributedReplayPlan
pub fn builder( multi_config_path: impl AsRef<Path>, ) -> CuResult<DistributedReplayBuilder>
pub fn assignment( &self, instance_id: u32, subsystem_id: &str, ) -> Option<&DistributedReplayAssignment>
Sourcepub fn start(self) -> CuResult<DistributedReplayEngine>
pub fn start(self) -> CuResult<DistributedReplayEngine>
Build a causal distributed replay engine from this validated plan.
Sourcepub fn start_recording_logs_under(
self,
output_root: impl AsRef<Path>,
) -> CuResult<DistributedReplayEngine>
pub fn start_recording_logs_under( self, output_root: impl AsRef<Path>, ) -> CuResult<DistributedReplayEngine>
Build a causal distributed replay engine and persist replayed logs under output_root.