Module monitoring

Module monitoring 

Some basic internal monitoring tooling Copper uses to monitor itself and the components it runs.

Structs

ComponentId
Strongly-typed index into CuMonitoringMetadata::components.
CopperListEntry
One message entry in CopperList slot order with resolved component identity.
CopperListInfo
CopperListIoStats
Reported data about CopperList IO for a single iteration.
CopperListLayout
Static monitor-side CopperList indexing layout.
CopperListView
Per-loop monitor view over CopperList metadata paired with static component mapping.
CountingAlloc
A simple allocator that counts the number of bytes allocated and deallocated.
CuDurationStatistics
A Specialized statistics object for CuDuration. It will also keep track of the jitter between the values.
CuListSlot
Strongly-typed CopperList slot index.
CuMonitoringMetadata
Immutable runtime-provided metadata passed once to CuMonitor::new.
CuMonitoringRuntime
Runtime-provided dynamic monitoring handles passed once to CuMonitor::new.
ExecutionMarker
Execution progress marker emitted by the runtime before running a component step.
LiveStatistics
Accumulative stat object that can give your some real time statistics. Uses a fixed-size bucketed histogram for accurate percentile calculations.
MonitorComponentMetadata
Static identity entry for one monitored runtime component.
MonitorConnection
MonitorExecutionProbe
Platform-neutral monitor view of runtime execution progress.
MonitorNode
MonitorTopology
NoMonitor
A do nothing monitor if no monitor is provided. This is basically defining the default behavior of Copper in case of error.
RuntimeExecutionProbe
Lock-free runtime-side progress probe.

Enums

ComponentType
Runtime component category used by monitoring metadata and topology.
CuComponentState
Lifecycle state of a monitored component.
Decision
Monitor decision to be taken when a component step errored out.

Traits

CuMonitor
Runtime monitoring contract implemented by monitor components.
CuPayloadSize
Lightweight trait to estimate the amount of data a payload will contribute when serialized. Default implementations return the stack size; specific types override to report dynamic data.

Functions

build_monitor_topology
Derive a monitor-friendly topology from the runtime configuration.
panic_payload_to_string

Type Aliases

ExecutionProbeHandle