pub struct RuntimeExecutionProbe { /* private fields */ }Expand description
Lock-free runtime-side progress probe.
The runtime writes execution markers directly into this probe from the hot path (without calling monitor fan-out callbacks), and monitors can read a coherent snapshot from watchdog threads when diagnosing stalls.
Implementations
Sourceimpl RuntimeExecutionProbe
impl RuntimeExecutionProbe
pub fn record(&self, marker: ExecutionMarker)
pub fn sequence(&self) -> usize
pub fn marker(&self) -> Option<ExecutionMarker>