Structs
- Aligned
Buffer - A buffer that is aligned to a specific size with the Element of type E.
- CuHandle
- A shareable handle to an Array coming from a pool (either host or device).
- CuHost
Memory Pool - A pool of host memory buffers.
- CuShared
Memory Buffer - CuShared
Memory Handle Descriptor - CuShared
Memory Pool - A pool of fixed-size shared-memory buffers that can be leased to a child process without copying the underlying bytes.
- Shared
Handle Serialization Guard
Enums
- CuHandle
Inner - A Handle to a Buffer. For onboard usages, the buffer should be Pooled (ie, coming from a preallocated pool). The Detached version is for offline usages where we don’t really need a pool to deserialize them.
- CuShared
Memory Element Type
Traits
- Array
Like - CuPool
- A CuPool is a pool of buffers that can be shared between different parts of the code. Handles can be stored locally in the tasks and shared between them.
- Device
CuPool - A device memory pool can copy data from a device to a host memory pool on top.
- Element
Type - Basic Type that can be used in a buffer in a CuPool.
- Pool
Monitor - Trait for a Pool to exposed to be monitored by the monitoring API.
Functions
- enable_
shared_ handle_ serialization - pools_
statistics - Get the list of pools and their statistics. We use SmallVec here to avoid heap allocations while the stack is running.