ReflectTaskIntrospection

Trait ReflectTaskIntrospection 

pub trait ReflectTaskIntrospection {
    // Required methods
    fn reflect_task(&self, task_id: &str) -> Option<&dyn Reflect>;
    fn reflect_task_mut(&mut self, task_id: &str) -> Option<&mut dyn Reflect>;

    // Provided method
    fn register_reflect_types(_registry: &mut TypeRegistry) { ... }
}
Runtime task-reflect contract exposed by generated Copper applications.

Required Methods

fn reflect_task(&self, task_id: &str) -> Option<&dyn Reflect>

Returns a reflected immutable task instance for the given task id.

fn reflect_task_mut(&mut self, task_id: &str) -> Option<&mut dyn Reflect>

Returns a reflected mutable task instance for the given task id.

Provided Methods

fn register_reflect_types(_registry: &mut TypeRegistry)

Registers reflected schema types for this mission’s app (tasks, messages, bridges).

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors