CuSimBridge

Struct CuSimBridge 

pub struct CuSimBridge<Tx: BridgeChannelSet + 'static, Rx: BridgeChannelSet + 'static> { /* private fields */ }
Placeholder bridge used in simulation when a bridge is configured with run_in_sim: false.

This bridge is parameterized directly by the Tx/Rx channel sets generated from configuration, so the original bridge type does not need to compile in simulation mode.